Remove a relationship table from the database
Source:R/database-write-relationship.R
remove_relationship_table.RdRemoves a relationship table and its metadata entry from the database.
R/database-write-relationship.R
remove_relationship_table.RdRemoves a relationship table and its metadata entry from the database.