Skip to contents

Updates metadata fields for an existing mapping table without re-adding the data. Currently supports updating col_filters.

Usage

update_mapping_metadata(
  from_code_type,
  to_code_type,
  map_version = "latest",
  ...,
  col_filters = NULL
)

Arguments

from_code_type

The source coding system (e.g. "Read 3").

to_code_type

The target coding system (e.g. "ICD-10").

map_version

The version to update. Use "latest" (default) to update the most recent version.

...

These dots are for future extensions and must be empty.

col_filters

Column filter specification to set. See mapping_metadata() for the format. Use NULL to clear existing filters.

Value

TRUE invisibly if successful.