Update relationship table metadata
Source:R/database-write-relationship.R
update_relationship_metadata.RdUpdates metadata fields for an existing relationship table without re-adding
the data. Currently supports updating col_filters.
Usage
update_relationship_metadata(
code_type,
relationship_version = "latest",
...,
col_filters = NULL
)Arguments
- code_type
The coding system type (e.g.
"SNOMED CT").- relationship_version
The version to update. Use
"latest"(default) to update the most recent version.- ...
These dots are for future extensions and must be empty.
- col_filters
Column filter specification to set. See
relationship_metadata()for the format. UseNULLto clear existing filters.
See also
relationship_metadata(), add_relationship_table()
Other Database management:
update_lookup_metadata(),
update_mapping_metadata()